@@ -6,7 +6,7 @@ k <- 3
 result <- Ckmeans.1d.dp(x, k)
 plot(result)
 plot(x, col=result$cluster, pch=result$cluster, cex=1.5,
-     main="Optimal k-means clustering given k",
+     main="Optimal univariate clustering given k",
      sub=paste("Number of clusters given:", k))
 abline(h=result$centers, col=1:k, lty="dashed", lwd=2)
 legend("bottomright", paste("Cluster", 1:k), col=1:k, pch=1:k, cex=1.5, bty="n")
@@ -37,11 +37,10 @@ y <- c(y1, y2)
 w <- y^8 # stress the peaks 
 res <- Ckmeans.1d.dp(t, k=c(1:10), w)
 plot(res)
-plot(t, w, main = "Time course segmentation", 
-     col=res$cluster, pch=res$cluster, 
-     xlab="Time t", ylab="Transformed intensity w", 
-     type="h")
+plot(t, w, main = "Time course segmentation / peak calling", 
+     col=res$cluster, pch=res$cluster, type="h", 
+     xlab="Time t", ylab="Transformed intensity w")
 abline(v=res$centers, col="chocolate", lty="dashed")
 text(res$centers, max(w) * .95, cex=0.75, font=2,
-     paste(round(res$size / sum(res$size) * 100, 2), "/100"))
+     paste(round(res$size / sum(res$size) * 100), "/ 100"))
 
